Crate rlsp_yaml_parser

Crate rlsp_yaml_parser 

Re-exports

pub use loader::LoadError;
pub use loader::LoadMode;
pub use loader::Loader;
pub use loader::LoaderBuilder;
pub use loader::LoaderOptions;
pub use loader::load;
pub use node::Document;
pub use node::Node;
pub use limits::MAX_ANCHOR_NAME_BYTES;
pub use limits::MAX_COLLECTION_DEPTH;
pub use limits::MAX_COMMENT_LEN;
pub use limits::MAX_DIRECTIVES_PER_DOC;
pub use limits::MAX_RESOLVED_TAG_LEN;
pub use limits::MAX_TAG_HANDLE_BYTES;
pub use limits::MAX_TAG_LEN;

Modules

encoding
limits
loader
Event-to-AST loader.
node
YAML AST node types.

Structs

Error
A parse error produced by the streaming parser.
Line
A single logical line extracted from the input.
LineBuffer
A one-line-lookahead buffer over a &'input str.
Pos
A position within the input stream.
Span
A half-open span [start, end) within the input stream.

Enums

BreakType
The type of line terminator that ends a Line.
Chomp
Block scalar chomping mode per YAML 1.2 8.1.1.2.
CollectionStyle
The style (block or flow) of a collection (sequence or mapping).
Event
A high-level YAML parse event.
ScalarStyle
The style in which a scalar value was written in the source.

Functions

parse_events
Parse a YAML string into a lazy event stream.